Module certutils

Module certutils 

Verious utilities for checking the content of a certificate.

Functions

get_common_names
Return the common name of the certificate. Usually will only contains one. May be empty.
get_dns_names
Return the DNS names in the subjectAlternativeNames of the certificate as well as its common name.