check_inclusion_proof

Function check_inclusion_proof 

pub async fn check_inclusion_proof(
    client: &Client,
    base_url: &Url,
    tree_size: u64,
    tree_hash: &[u8; 32],
    leaf_hash: &[u8; 32],
) -> Result<u64, Error>
Fetch the required inclusion proof from the server and see if it convinces us that leaf_hash is in the tree with hash tree_hash and size tree_size. On success, return the index number of the leaf corresponding with the hash.