pub fn get_entries<'a>(
client: &'a Client,
base_url: &'a Url,
range: Range<u64>,
batch_size: u64,
) -> impl Stream<Item = Result<Leaf, Error>> + 'aExpand description
Request leaf entries from the CT log. Does not verify if these entries are consistent with the tree or anything like that. Returns an iterator over the leaves.
After the first Err result, the iterator will not produce anything else.
Uses O(1) memory itself.