new_http_client

Function new_http_client 

pub fn new_http_client() -> Result<Client, Error>
Construct a new reqwest::Client to be used with the functions in this module. You don’t necessary need to use this.

The client constructed will not store cookie or follow redirect.