Module openssl_ffi

Module openssl_ffi 

Because openssl crate is incomplete.

Modules

foreign
Because openssl_sys crate is incomplete.

Structs

Sct
An owned reference to a openssl SCT struct.
SctRef
A reference to a openssl SCT struct.

Enums

SCTVersion
SignatureAlgorithm

Functions

sct_list_from_x509
x509_clone
x509_make_a_looks_like_issued_by_b
Set the issuer name of dst to be the subject name of src, and also set the authorityKeyIdentifier of a to the subjectKeyIdentifier of b.
x509_remove_poison
x509_remove_sct_list
x509_to_tbs

Type Aliases

SctList
An owned STACK_OF(SCT).