Leaf

Struct Leaf 

pub struct Leaf {
    pub hash: [u8; 32],
    pub timestamp: u64,
    pub is_pre_cert: bool,
    pub x509_chain: Vec<Vec<u8>>,
    pub tbs_cert: Option<Vec<u8>>,
    pub issuer_key_hash: Option<Vec<u8>>,
    pub extensions: Vec<u8>,
}
A parsed leaf.

Parse a JSON get-entries response to this with TryFrom<&jsons::LeafEntry>::try_from.

Fields

hash: [u8; 32]

What they call “leaf hash”.

timestamp: u64

The leaf timestamp provided by the log.

is_pre_cert: boolx509_chain: Vec<Vec<u8>>

The first cert is the end entity cert (or pre cert, if is_pre_cert is true), and the last is the root CA.

tbs_cert: Option<Vec<u8>>

When is_pre_cert is true, this contains the tbs certificate found at the leaf input data. You should verify that this is the same certificate as x509_chain[0], except not signed.

issuer_key_hash: Option<Vec<u8>>extensions: Vec<u8>

Raw extensions data. Ignored. Length not included.

Implementations

Source

impl Leaf

pub fn from_raw(leaf_input: &[u8], extra_data: &[u8]) -> Result<Self, Error>