pub struct SignedCertificateTimestamp {
pub log_id: [u8; 32],
pub timestamp: u64,
pub extensions_data: Vec<u8>,
pub entry: SctEntry,
pub signature_algorithm: SignatureAlgorithm,
pub raw_signature: Vec<u8>,
}Expand description
An unverified Signed Certificate Timestamp (SCT).
Fields
log_id: [u8; 32]timestamp: u64extensions_data: Vec<u8>entry: SctEntrysignature_algorithm: SignatureAlgorithmraw_signature: Vec<u8>Raw signature encoded in ASN.1
Implementations
Sourceimpl SignedCertificateTimestamp
impl SignedCertificateTimestamp
Sourcepub fn from_cert_sct_extension(
cert: &X509Ref,
issuer: &X509Ref,
) -> Result<Vec<SignedCertificateTimestamp>, Error>
pub fn from_cert_sct_extension( cert: &X509Ref, issuer: &X509Ref, ) -> Result<Vec<SignedCertificateTimestamp>, Error>
Extract a list of SCTs from the SCT List extension of the given openssl-parsed certificate, if the extension is there.
If the certificate does not contain the extension, Ok(vec![]) is returned.
Will not verify the signature. Call self.verify with the log’s public key to verify.
Sourcepub fn derive_leaf_hash(&self) -> [u8; 32]
pub fn derive_leaf_hash(&self) -> [u8; 32]
Derive the corresponding Merkle leaf hash from this SCTs.
Can be used to check inclusion, for example.