pub struct SignedTreeHead {
pub tree_size: u64,
pub timestamp: u64,
pub root_hash: [u8; 32],
pub signature: Vec<u8>,
}Expand description
An unverified signed tree head (STH), as returned from the server. This encapsulate the state of the tree at some point in time.
This struct stores the signature but does not store the public key or log id.
Fields
tree_size: u64timestamp: u64root_hash: [u8; 32]signature: Vec<u8>Digitally signed struct
Implementations