pub async fn check_tree_head(
client: &Client,
base_url: &Url,
pub_key: &PKey<Public>,
) -> Result<SignedTreeHead, Error>Expand description
Check, verify and return the latest tree head from the CT log at
base_url.
This function is only useful to those who want to do some custom CT API
calling. CTClient will automatically update its cache of
tree root. If you use CTClient, call
CTClient::get_checked_tree_head
instead.
Params
client: Areqwest::Clientinstance. SeeCTClient::get_reqwest_client