SignedCertificateTimestamp

Struct SignedCertificateTimestamp 

pub struct SignedCertificateTimestamp {
    pub log_id: [u8; 32],
    pub timestamp: u64,
    pub extensions_data: Vec<u8>,
    pub entry: SctEntry,
    pub signature_algorithm: SignatureAlgorithm,
    pub raw_signature: Vec<u8>,
}
An unverified Signed Certificate Timestamp (SCT).

Fields

log_id: [u8; 32]timestamp: u64extensions_data: Vec<u8>entry: SctEntrysignature_algorithm: SignatureAlgorithmraw_signature: Vec<u8>

Raw signature encoded in ASN.1

Implementations

Source

impl SignedCertificateTimestamp

pub fn from_cert_sct_extension( cert: &X509Ref, issuer: &X509Ref, ) -> Result<Vec<SignedCertificateTimestamp>, Error>

Extract a list of SCTs from the SCT List extension of the given openssl-parsed certificate, if the extension is there.

If the certificate does not contain the extension, Ok(vec![]) is returned.

Will not verify the signature. Call self.verify with the log’s public key to verify.

pub fn derive_leaf_hash(&self) -> [u8; 32]

Derive the corresponding Merkle leaf hash from this SCTs.

Can be used to check inclusion, for example.

pub fn verify(&self, log_public_key: &PKey<Public>) -> Result<(), Error>

Check the signature in this SCT.

To get the log public key, lookup the log with self.log_id by e.g. using crate::google_log_list::LogList::find_by_id.